Crate kcode_web_libs

Crate kcode_web_libs 

Six-operation managed web-library boundary.

Structs

Error
A bounded, non-secret operational error.
File
Lib
One opened optimistic snapshot of a managed web library.

Functions

create
Creates a managed web library with a minimal version-0.1.0 ES module.
docs
Returns the manifest version and root Documentation.md.
open
Opens the current complete source generation of a managed web library.

Type Aliases

Result